@@ -1,7 +1,10 @@
 """
 Sage Intacct Python SDK
 """
-from .apis import *
+from .apis import ApiBase, Contacts, Locations, Employees, Accounts, ExpenseTypes, Attachments, ExpenseReports,\
+    Vendors, Bills, Projects, Departments, ChargeCardAccounts, ChargeCardTransactions, Customers, Items,\
+    APPayments, Reimbursements, CheckingAccounts, SavingsAccounts, Tasks, ExpensePaymentTypes, Dimensions,\
+    DimensionValues
 
 
 class SageIntacctSDK:
@@ -25,8 +28,6 @@ class SageIntacctSDK:
         self.__company_id = company_id
         self.__user_password = user_password
 
-        self.__access_token = None
-
         self.api_base = ApiBase()
         self.contacts = Contacts()
         self.locations = Locations()
@@ -47,6 +48,8 @@ class SageIntacctSDK:
         self.reimbursements = Reimbursements()
         self.checking_accounts = CheckingAccounts()
         self.savings_accounts = SavingsAccounts()
+        self.dimensions = Dimensions()
+        self.dimension_values = DimensionValues()
         self.tasks = Tasks()
         self.expense_payment_types = ExpensePaymentTypes()
 
@@ -78,6 +81,8 @@ class SageIntacctSDK:
         self.reimbursements.set_sender_id(self.__sender_id)
         self.checking_accounts.set_sender_id(self.__sender_id)
         self.savings_accounts.set_sender_id(self.__sender_id)
+        self.dimensions.set_sender_id(self.__sender_id)
+        self.dimension_values.set_sender_id(self.__sender_id)
         self.tasks.set_sender_id(self.__sender_id)
         self.expense_payment_types.set_sender_id(self.__sender_id)
 
@@ -105,6 +110,8 @@ class SageIntacctSDK:
         self.reimbursements.set_sender_password(self.__sender_password)
         self.checking_accounts.set_sender_password(self.__sender_password)
         self.savings_accounts.set_sender_password(self.__sender_password)
+        self.dimensions.set_sender_password(self.__sender_password)
+        self.dimension_values.set_sender_password(self.__sender_password)
         self.tasks.set_sender_password(self.__sender_password)
         self.expense_payment_types.set_sender_password(self.__sender_password)
 
@@ -112,7 +119,7 @@ class SageIntacctSDK:
         """
         Update the session id and change it in all API objects.
         """
-        self.__session_id = self.api_base._get_session_id(self.__user_id, self.__company_id, self.__user_password)
+        self.__session_id = self.api_base.get_session_id(self.__user_id, self.__company_id, self.__user_password)
         self.api_base.set_session_id(self.__session_id)
         self.contacts.set_session_id(self.__session_id)
         self.locations.set_session_id(self.__session_id)
@@ -133,5 +140,7 @@ class SageIntacctSDK:
         self.reimbursements.set_session_id(self.__session_id)
         self.checking_accounts.set_session_id(self.__session_id)
         self.savings_accounts.set_session_id(self.__session_id)
+        self.dimensions.set_session_id(self.__session_id)
+        self.dimension_values.set_session_id(self.__session_id)
         self.tasks.set_session_id(self.__session_id)
         self.expense_payment_types.set_session_id(self.__session_id)
